#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector-instances
version:              3.4.3
visibility:           public
id:                   vector-instances-3.4.3-GClTgJEsdbKKm33RPn2FIA
key:                  vector-instances-3.4.3-GClTgJEsdbKKm33RPn2FIA
license:              BSD-3-Clause
maintainer:           ekmett@gmail.com
author:               Edward Kmett
homepage:             http://github.com/ekmett/vector-instances
synopsis:             Orphan Instances for '\''Data.Vector'\''
description:          Orphan Instances for '\''Data.Vector'\''.
category:             Data, Data Structures
abi:                  e246daca5939e2009a4d0df395961a00
exposed:              True
exposed-modules:      Data.Vector.Instances
import-dirs:          /usr/lib/ghc-9.6.6/site-local/vector-instances-3.4.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/vector-instances-3.4.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/vector-instances-3.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-instances
hs-libraries:         HSvector-instances-3.4.3-GClTgJEsdbKKm33RPn2FIA
depends:
    base-4.18.2.1 comonad-5.0.9-GlmJp6SPyoDLAPgtcgZh46
    hashable-1.4.7.0-LE3bCdm1Wgy6IgVYkRoAlQ
    keys-3.12.4-IPLRPIdgYluDu2HJOVGLs7
    pointed-5.0.5-AOwZR4tXHp4jOjYnH9leY
    semigroupoids-6.0.1-DgRGywcI4cKAo6YP4lFHsp
    vector-0.13.2.0-KFVS0U8K6eML5O0P7tVbRi

haddock-interfaces:
    /usr/share/doc/haskell-vector-instances/html/vector-instances.haddock

haddock-html:         /usr/share/doc/haskell-vector-instances/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

